@@ -5,7 +5,7 @@
    pstoeditoptions.h : This file is part of pstoedit
    definition of program options 
 
-   Copyright (C) 1993 - 2011 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2012 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -132,6 +132,7 @@ public:
 	OptionT < RSString, RSStringValueExtractor> replacementfont;// = "Courier";
  	OptionT < bool, BoolTrueExtractor > nomaptoisolatin1 ;//= false;
 	OptionT < bool, BoolTrueExtractor > withdisplay ;//= false;
+	OptionT < RSString, RSStringValueExtractor> pngimage ;
 	OptionT < bool, BoolTrueExtractor > quiet ;//= false;
 	OptionT < bool, BoolTrueExtractor > noquit ;//= false;
 	OptionT < bool, BoolTrueExtractor > nocurves ;//= false;		// normally curves are shown as curves if backend supports
@@ -142,6 +143,7 @@ public:
 	OptionT < bool, BoolTrueExtractor > drawtext ;//= false;
 	OptionT < bool, BoolTrueExtractor > autodrawtext ;//= false;
 	OptionT < bool, BoolTrueExtractor > disabledrawtext ;//= false;
+	OptionT < bool, BoolTrueExtractor > DrawGlyphBitmaps ;//= false; 
 	OptionT < bool, BoolTrueExtractor > correctdefinefont ;//= false;
 
 	OptionT < bool, BoolTrueExtractor > ptioption;
@@ -206,7 +208,7 @@ public:
 	nameOfInputFile  (0),
 	nameOfOutputFile (0),	// can contain %d for page splitting
 
-	nameOfIncludeFile	(true, "-include","name of a PostScript file to be included",g_t,"name of an option include file" ,
+	nameOfIncludeFile	(true, "-include","name of a PostScript file to be included",g_t,"name of PostScript file to be included" ,
 		"This options allows to specify an additional PostScript file that will be "
 		"executed just before the normal input is read. This is helpful for "
 		"including specific page settings or for disabling potentially unsafe "
@@ -230,6 +232,10 @@ public:
 		"Open a display during processing by Ghostscript. Some files "
 		"only work correctly this way. ",
 		false),
+
+	pngimage	(true, "-pngimage","filename - for debugging purpose mainly. Write result of processing also to a PNG file.",t_t,
+	"for debugging purpose mainly. Write result of processing also to a PNG file" ,UseDefaultDoku,(const char*) 0),
+
 	quiet				(true, "-q",noArgument,b_t,"quiet mode - do not write startup message" ,
 		UseDefaultDoku,
 		false),
@@ -288,6 +294,11 @@ public:
 		"instead of showing it as text. This may produce incorrect results, but in some cases it might nevertheless be useful. \"Use at own risk\". ", 
 		false),
 
+	DrawGlyphBitmaps		(true, "-dgbm",noArgument,t_t,"experimental - draw also bitmaps generated by fonts/glyphs" , 
+		UseDefaultDoku, 
+		false),
+
+
 	correctdefinefont	(true, "-correctdefinefont",noArgument,t_t,"apply some \"corrective\" actions to definefont - use this for ChemDraw generated PostScript files", 
 		"Some PostScript files, e.g. such as generated by ChemDraw, "
 		"use the PostScript definefont operator in way that is incompatible with "
@@ -576,6 +587,7 @@ public:
 	ADD(replacementfont);
 	ADD(nomaptoisolatin1);
 	ADD(withdisplay);
+	ADD(pngimage);
 	ADD(quiet);
 	ADD(noquit);
 	ADD(nocurves );
@@ -586,6 +598,7 @@ public:
 	ADD(drawtext);
 	ADD(autodrawtext);
 	ADD(disabledrawtext);
+	ADD(DrawGlyphBitmaps);
 	ADD(correctdefinefont);
 
 	ADD(ptioption);
